"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, import_task_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more import tasks, each identified by their import ID. Each import task has a number of records that can identify servers or applications.  AWS Application Discovery Service has built-in matching logic that will identify when discovered servers match existing entries that you've previously discovered, the information for the already-existing discovered server is updated. When you delete an import task that contains records that were used to match, the information in those matched records that comes from the deleted records will also be deleted.

    Args:
        import_task_ids(List): The IDs for the import tasks that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.delete_import_data.batch(ctx, import_task_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.delete_import_data.batch import_task_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="batch_delete_import_data",
        op_kwargs={"importTaskIds": import_task_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, app_id: str, backend_environment_name: str, job_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific job.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        job_id(str): The ID for the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.job.get(
                ctx, app_id=value, backend_environment_name=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.job.get app_id=value, backend_environment_name=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_backend_job",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "JobId": job_id,
        },
    )


async def list_all(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    job_id: str = None,
    max_results: int = None,
    next_token: str = None,
    operation: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the jobs for the backend of an Amplify app.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        job_id(str, optional): The ID for the job. Defaults to None.
        max_results(int, optional): The maximum number of results that you want in the response. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        operation(str, optional): Filters the list of response objects to include only those with the specified operation name. Defaults to None.
        status(str, optional): Filters the list of response objects to include only those with the specified status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.job.list_all(
                ctx, app_id=value, backend_environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.job.list_all app_id=value, backend_environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="list_backend_jobs",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Operation": operation,
            "Status": status,
        },
    )


async def update(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    job_id: str,
    operation: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specific job.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        job_id(str): The ID for the job.
        operation(str, optional): Filters the list of response objects to include only those with the specified operation name. Defaults to None.
        status(str, optional): Filters the list of response objects to include only those with the specified status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.job.update(
                ctx, app_id=value, backend_environment_name=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.job.update app_id=value, backend_environment_name=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="update_backend_job",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "JobId": job_id,
            "Operation": operation,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def begin(
    hub,
    ctx,
    resource_arn: str,
    secret_arn: str,
    database: str = None,
    schema: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a SQL transaction.  <important> <p>A transaction can run for a maximum of 24 hours. A transaction is terminated and rolled back automatically after 24 hours.</p> <p>A transaction times out if no calls use its transaction ID in three minutes. If a transaction times out before it's committed, it's rolled back automatically.</p> <p>DDL statements inside a transaction cause an implicit commit. We recommend that you run each DDL statement in a separate <code>ExecuteStatement</code> call with <code>continueAfterTimeout</code> enabled.</p> </important>

    Args:
        database(str, optional): The name of the database. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
        schema(str, optional): The name of the database schema. Defaults to None.
        secret_arn(str): The name or ARN of the secret that enables access to the DB cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds_data.transaction.begin(
                ctx, resource_arn=value, secret_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds_data.transaction.begin resource_arn=value, secret_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds-data",
        operation="begin_transaction",
        op_kwargs={
            "database": database,
            "resourceArn": resource_arn,
            "schema": schema,
            "secretArn": secret_arn,
        },
    )


async def commit(
    hub, ctx, resource_arn: str, secret_arn: str, transaction_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Ends a SQL transaction started with the BeginTransaction operation and commits the changes.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
        secret_arn(str): The name or ARN of the secret that enables access to the DB cluster.
        transaction_id(str): The identifier of the transaction to end and commit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds_data.transaction.commit(
                ctx, resource_arn=value, secret_arn=value, transaction_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds_data.transaction.commit resource_arn=value, secret_arn=value, transaction_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds-data",
        operation="commit_transaction",
        op_kwargs={
            "resourceArn": resource_arn,
            "secretArn": secret_arn,
            "transactionId": transaction_id,
        },
    )


async def rollback(
    hub, ctx, resource_arn: str, secret_arn: str, transaction_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Performs a rollback of a transaction. Rolling back a transaction cancels its changes.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
        secret_arn(str): The name or ARN of the secret that enables access to the DB cluster.
        transaction_id(str): The identifier of the transaction to roll back.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds_data.transaction.rollback(
                ctx, resource_arn=value, secret_arn=value, transaction_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds_data.transaction.rollback resource_arn=value, secret_arn=value, transaction_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds-data",
        operation="rollback_transaction",
        op_kwargs={
            "resourceArn": resource_arn,
            "secretArn": secret_arn,
            "transactionId": transaction_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, rule_group_id: str = None, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of ActivatedRule objects.

    Args:
        rule_group_id(str, optional): The RuleGroupId of the RuleGroup for which you want to get a list of ActivatedRule objects. Defaults to None.
        next_marker(str, optional): If you specify a value for Limit and you have more ActivatedRules than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of ActivatedRules. For the second and subsequent ListActivatedRulesInRuleGroup requests, specify the value of NextMarker from the previous response to get information about another batch of ActivatedRules. Defaults to None.
        limit(int, optional): Specifies the number of ActivatedRules that you want AWS WAF to return for this request. If you have more ActivatedRules than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of ActivatedRules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.activated_rule_in_rule_group.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.activated_rule_in_rule_group.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_activated_rules_in_rule_group",
        op_kwargs={
            "RuleGroupId": rule_group_id,
            "NextMarker": next_marker,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, fleet_arn: str, authorization_provider_type: str, domain_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a website authorization provider with a specified fleet. This is used to authorize users against associated websites in the company network.

    Args:
        fleet_arn(str): The ARN of the fleet.
        authorization_provider_type(str): The authorization provider type.
        domain_name(str, optional): The domain name of the authorization provider. This applies only to SAML-based authorization providers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.authorization_provider.associate(
                ctx, fleet_arn=value, authorization_provider_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.authorization_provider.associate fleet_arn=value, authorization_provider_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="associate_website_authorization_provider",
        op_kwargs={
            "FleetArn": fleet_arn,
            "AuthorizationProviderType": authorization_provider_type,
            "DomainName": domain_name,
        },
    )


async def disassociate(
    hub, ctx, fleet_arn: str, authorization_provider_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a website authorization provider from a specified fleet. After the disassociation, users can't load any associated websites that require this authorization provider.

    Args:
        fleet_arn(str): The ARN of the fleet.
        authorization_provider_id(str): A unique identifier for the authorization provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.authorization_provider.disassociate(
                ctx, fleet_arn=value, authorization_provider_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.authorization_provider.disassociate fleet_arn=value, authorization_provider_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="disassociate_website_authorization_provider",
        op_kwargs={
            "FleetArn": fleet_arn,
            "AuthorizationProviderId": authorization_provider_id,
        },
    )


async def list_all(
    hub, ctx, fleet_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of website authorization providers associated with a specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        max_results(int, optional): The maximum number of results to be included in the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.authorization_provider.list_all(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.authorization_provider.list_all fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="list_website_authorization_providers",
        op_kwargs={
            "FleetArn": fleet_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the resource as managed by the Data Catalog. When you deregister a path, Lake Formation removes the path from the inline policy attached to your service-linked role.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to deregister.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.init.deregister(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.init.deregister resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="deregister_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def describe(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current data access role for the given resource registered in AWS Lake Formation.

    Args:
        resource_arn(str): The resource ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.init.describe(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.init.describe resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="describe_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def list_all(
    hub,
    ctx,
    filter_condition_list: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resources registered to be managed by the Data Catalog.

    Args:
        filter_condition_list(List, optional): Any applicable row-level and/or column-level filtering conditions for the resources. Defaults to None.
        max_results(int, optional): The maximum number of resource results. Defaults to None.
        next_token(str, optional): A continuation token, if this is not the first call to retrieve these resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="list_resources",
        op_kwargs={
            "FilterConditionList": filter_condition_list,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def register(
    hub,
    ctx,
    resource_arn: str,
    use_service_linked_role: bool = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers the resource as managed by the Data Catalog. To add or update data, Lake Formation needs read/write access to the chosen Amazon S3 path. Choose a role that you know has permission to do this, or choose the AWSServiceRoleForLakeFormationDataAccess service-linked role. When you register the first Amazon S3 path, the service-linked role and a new inline policy are created on your behalf. Lake Formation adds the first path to the inline policy and attaches it to the service-linked role. When you register subsequent paths, Lake Formation adds the path to the existing policy. The following request registers a new location and gives AWS Lake Formation permission to use the service-linked role to access that location.  ResourceArn = arn:aws:s3:::my-bucket UseServiceLinkedRole = true  If UseServiceLinkedRole is not set to true, you must provide or set the RoleArn:  arn:aws:iam::12345:role/my-data-access-role

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to register.
        use_service_linked_role(bool, optional): Designates an AWS Identity and Access Management (IAM) service-linked role by registering this role with the Data Catalog. A service-linked role is a unique type of IAM role that is linked directly to Lake Formation. For more information, see Using Service-Linked Roles for Lake Formation. Defaults to None.
        role_arn(str, optional): The identifier for the role that registers the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.init.register(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.init.register resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="register_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "UseServiceLinkedRole": use_service_linked_role,
            "RoleArn": role_arn,
        },
    )


async def update(hub, ctx, role_arn: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the data access role used for vending access to the given (registered) resource in AWS Lake Formation.

    Args:
        role_arn(str): The new role to use for the given resource registered in AWS Lake Formation.
        resource_arn(str): The resource ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.init.update(
                ctx, role_arn=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.init.update role_arn=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="update_resource",
        op_kwargs={"RoleArn": role_arn, "ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, asset_type: str, description: str, name: str, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation creates a data set.

    Args:
        asset_type(str): The type of file your data is stored in. Currently, the supported asset type is S3_SNAPSHOT.
        description(str): A description for the data set. This value can be up to 16,348 characters long.
        name(str): The name of the data set.
        tags(Dict, optional): A data set tag is an optional label that you can assign to a data set when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to these data sets and revisions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.data_set_.init.create(
                ctx, asset_type=value, description=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.data_set_.init.create asset_type=value, description=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="create_data_set",
        op_kwargs={
            "AssetType": asset_type,
            "Description": description,
            "Name": name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, data_set_id: str) -> None:
    r"""
    **Autogenerated function**

    This operation deletes a data set.

    Args:
        data_set_id(str): The unique identifier for a data set.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.data_set_.init.delete(ctx, data_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.data_set_.init.delete data_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="delete_data_set",
        op_kwargs={"DataSetId": data_set_id},
    )


async def get(hub, ctx, data_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns information about a data set.

    Args:
        data_set_id(str): The unique identifier for a data set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.data_set_.init.get(ctx, data_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.data_set_.init.get data_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="get_data_set",
        op_kwargs={"DataSetId": data_set_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, origin: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists your data sets. When listing by origin OWNED, results are sorted by CreatedAt in descending order. When listing by origin ENTITLED, there is no order and the maxResults parameter is ignored.

    Args:
        max_results(int, optional): The maximum number of results returned by a single call. Defaults to None.
        next_token(str, optional): The token value retrieved from a previous call to access the next page of results. Defaults to None.
        origin(str, optional): A property that defines the data set as OWNED by the account (for providers) or ENTITLED to the account (for subscribers). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.data_set_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.data_set_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="list_data_sets",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Origin": origin,
        },
    )


async def update(
    hub, ctx, data_set_id: str, description: str = None, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation updates a data set.

    Args:
        data_set_id(str): The unique identifier for a data set.
        description(str, optional): The description for the data set. Defaults to None.
        name(str, optional): The name of the data set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.data_set_.init.update(ctx, data_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.data_set_.init.update data_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="update_data_set",
        op_kwargs={"DataSetId": data_set_id, "Description": description, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def decrypt(
    hub,
    ctx,
    ciphertext_blob: bytes,
    encryption_context: Dict = None,
    grant_tokens: List = None,
    key_id: str = None,
    encryption_algorithm: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Decrypts ciphertext that was encrypted by a AWS KMS customer master key (CMK) using any of the following operations:    Encrypt     GenerateDataKey     GenerateDataKeyPair     GenerateDataKeyWithoutPlaintext     GenerateDataKeyPairWithoutPlaintext    You can use this operation to decrypt ciphertext that was encrypted under a symmetric or asymmetric CMK. When the CMK is asymmetric, you must specify the CMK and the encryption algorithm that was used to encrypt the ciphertext. For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. The Decrypt operation also decrypts ciphertext that was encrypted outside of AWS KMS by the public key in an AWS KMS asymmetric CMK. However, it cannot decrypt ciphertext produced by other libraries, such as the AWS Encryption SDK or Amazon S3 client-side encryption. These libraries return a ciphertext format that is incompatible with AWS KMS. If the ciphertext was encrypted under a symmetric CMK, the KeyId parameter is optional. AWS KMS can get this information from metadata that it adds to the symmetric ciphertext blob. This feature adds durability to your implementation by ensuring that authorized users can decrypt ciphertext decades after it was encrypted, even if they've lost track of the CMK ID. However, specifying the CMK is always recommended as a best practice. When you use the KeyId parameter to specify a CMK, AWS KMS only uses the CMK you specify. If the ciphertext was encrypted under a different CMK, the Decrypt operation fails. This practice ensures that you use the CMK that you intend. Whenever possible, use key policies to give users permission to call the Decrypt operation on a particular CMK, instead of using IAM policies. Otherwise, you might create an IAM user policy that gives the user Decrypt permission on all CMKs. This user could decrypt ciphertext that was encrypted by CMKs in other accounts if the key policy for the cross-account CMK permits it. If you must use an IAM policy for Decrypt permissions, limit the user to particular CMKs or particular trusted accounts. For details, see Best practices for IAM policies in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. You can decrypt a ciphertext using a CMK in a different AWS account.  Required permissions: kms:Decrypt (key policy)  Related operations:     Encrypt     GenerateDataKey     GenerateDataKeyPair     ReEncrypt

    Args:
        ciphertext_blob(bytes): Ciphertext to be decrypted. The blob includes metadata.
        encryption_context(Dict, optional): Specifies the encryption context to use when decrypting the data. An encryption context is valid only for cryptographic operations with a symmetric CMK. The standard asymmetric encryption algorithms that AWS KMS uses do not support an encryption context. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens.  Use a grant token when your permission to call this operation comes from a newly created grant that has not yet achieved eventual consistency. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.
        key_id(str, optional): Specifies the customer master key (CMK) that AWS KMS uses to decrypt the ciphertext. Enter a key ID of the CMK that was used to encrypt the ciphertext. This parameter is required only when the ciphertext was encrypted under an asymmetric CMK. If you used a symmetric CMK, AWS KMS can get the CMK from metadata that it adds to the symmetric ciphertext blob. However, it is always recommended as a best practice. This practice ensures that you use the CMK that you intend. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases. Defaults to None.
        encryption_algorithm(str, optional): Specifies the encryption algorithm that will be used to decrypt the ciphertext. Specify the same algorithm that was used to encrypt the data. If you specify a different algorithm, the Decrypt operation fails. This parameter is required only when the ciphertext was encrypted under an asymmetric CMK. The default value, SYMMETRIC_DEFAULT, represents the only supported algorithm that is valid for symmetric CMKs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.init.decrypt(ctx, ciphertext_blob=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.init.decrypt ciphertext_blob=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="decrypt",
        op_kwargs={
            "CiphertextBlob": ciphertext_blob,
            "EncryptionContext": encryption_context,
            "GrantTokens": grant_tokens,
            "KeyId": key_id,
            "EncryptionAlgorithm": encryption_algorithm,
        },
    )


async def encrypt(
    hub,
    ctx,
    key_id: str,
    plaintext: bytes,
    encryption_context: Dict = None,
    grant_tokens: List = None,
    encryption_algorithm: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Encrypts plaintext into ciphertext by using a customer master key (CMK). The Encrypt operation has two primary use cases:   You can encrypt small amounts of arbitrary data, such as a personal identifier or database password, or other sensitive information.    You can use the Encrypt operation to move encrypted data from one AWS Region to another. For example, in Region A, generate a data key and use the plaintext key to encrypt your data. Then, in Region A, use the Encrypt operation to encrypt the plaintext data key under a CMK in Region B. Now, you can move the encrypted data and the encrypted data key to Region B. When necessary, you can decrypt the encrypted data key and the encrypted data entirely within in Region B.   You don't need to use the Encrypt operation to encrypt a data key. The GenerateDataKey and GenerateDataKeyPair operations return a plaintext data key and an encrypted copy of that data key. When you encrypt data, you must specify a symmetric or asymmetric CMK to use in the encryption operation. The CMK must have a KeyUsage value of ENCRYPT_DECRYPT. To find the KeyUsage of a CMK, use the DescribeKey operation.  If you use a symmetric CMK, you can use an encryption context to add additional security to your encryption operation. If you specify an EncryptionContext when encrypting data, you must specify the same encryption context (a case-sensitive exact match) when decrypting the data. Otherwise, the request to decrypt fails with an InvalidCiphertextException. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. If you specify an asymmetric CMK, you must also specify the encryption algorithm. The algorithm must be compatible with the CMK type.  When you use an asymmetric CMK to encrypt or reencrypt data, be sure to record the CMK and encryption algorithm that you choose. You will be required to provide the same CMK and encryption algorithm when you decrypt the data. If the CMK and algorithm do not match the values used to encrypt the data, the decrypt operation fails. You are not required to supply the CMK ID and encryption algorithm when you decrypt with symmetric CMKs because AWS KMS stores this information in the ciphertext blob. AWS KMS cannot store metadata in ciphertext generated with asymmetric keys. The standard format for asymmetric key ciphertext does not include configurable fields.  The maximum size of the data that you can encrypt varies with the type of CMK and the encryption algorithm that you choose.   Symmetric CMKs    SYMMETRIC_DEFAULT: 4096 bytes      RSA_2048     RSAES_OAEP_SHA_1: 214 bytes    RSAES_OAEP_SHA_256: 190 bytes      RSA_3072     RSAES_OAEP_SHA_1: 342 bytes    RSAES_OAEP_SHA_256: 318 bytes      RSA_4096     RSAES_OAEP_SHA_1: 470 bytes    RSAES_OAEP_SHA_256: 446 bytes     The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:Encrypt (key policy)  Related operations:     Decrypt     GenerateDataKey     GenerateDataKeyPair

    Args:
        key_id(str): Identifies the customer master key (CMK) to use in the encryption operation. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        plaintext(bytes): Data to be encrypted.
        encryption_context(Dict, optional): Specifies the encryption context that will be used to encrypt the data. An encryption context is valid only for cryptographic operations with a symmetric CMK. The standard asymmetric encryption algorithms that AWS KMS uses do not support an encryption context.  An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.
        encryption_algorithm(str, optional): Specifies the encryption algorithm that AWS KMS will use to encrypt the plaintext message. The algorithm must be compatible with the CMK that you specify. This parameter is required only for asymmetric CMKs. The default value, SYMMETRIC_DEFAULT, is the algorithm used for symmetric CMKs. If you are using an asymmetric CMK, we recommend RSAES_OAEP_SHA_256. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.init.encrypt(ctx, key_id=value, plaintext=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.init.encrypt key_id=value, plaintext=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="encrypt",
        op_kwargs={
            "KeyId": key_id,
            "Plaintext": plaintext,
            "EncryptionContext": encryption_context,
            "GrantTokens": grant_tokens,
            "EncryptionAlgorithm": encryption_algorithm,
        },
    )


async def sign(
    hub,
    ctx,
    key_id: str,
    message: bytes,
    signing_algorithm: str,
    message_type: str = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a digital signature for a message or message digest by using the private key in an asymmetric CMK. To verify the signature, use the Verify operation, or use the public key in the same asymmetric CMK outside of AWS KMS. For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. Digital signatures are generated and verified by using asymmetric key pair, such as an RSA or ECC pair that is represented by an asymmetric customer master key (CMK). The key owner (or an authorized user) uses their private key to sign a message. Anyone with the public key can verify that the message was signed with that particular private key and that the message hasn't changed since it was signed.  To use the Sign operation, provide the following information:   Use the KeyId parameter to identify an asymmetric CMK with a KeyUsage value of SIGN_VERIFY. To get the KeyUsage value of a CMK, use the DescribeKey operation. The caller must have kms:Sign permission on the CMK.   Use the Message parameter to specify the message or message digest to sign. You can submit messages of up to 4096 bytes. To sign a larger message, generate a hash digest of the message, and then provide the hash digest in the Message parameter. To indicate whether the message is a full message or a digest, use the MessageType parameter.   Choose a signing algorithm that is compatible with the CMK.     When signing a message, be sure to record the CMK and the signing algorithm. This information is required to verify the signature.  To verify the signature that this operation generates, use the Verify operation. Or use the GetPublicKey operation to download the public key and then use the public key to verify the signature outside of AWS KMS.  The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:Sign (key policy)  Related operations: Verify

    Args:
        key_id(str): Identifies an asymmetric CMK. AWS KMS uses the private key in the asymmetric CMK to sign the message. The KeyUsage type of the CMK must be SIGN_VERIFY. To find the KeyUsage of a CMK, use the DescribeKey operation. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        message(bytes): Specifies the message or message digest to sign. Messages can be 0-4096 bytes. To sign a larger message, provide the message digest. If you provide a message, AWS KMS generates a hash digest of the message and then signs it.
        message_type(str, optional): Tells AWS KMS whether the value of the Message parameter is a message or message digest. The default value, RAW, indicates a message. To indicate a message digest, enter DIGEST. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.
        signing_algorithm(str): Specifies the signing algorithm to use when signing the message.  Choose an algorithm that is compatible with the type and size of the specified asymmetric CMK.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.init.sign(
                ctx, key_id=value, message=value, signing_algorithm=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.init.sign key_id=value, message=value, signing_algorithm=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="sign",
        op_kwargs={
            "KeyId": key_id,
            "Message": message,
            "MessageType": message_type,
            "GrantTokens": grant_tokens,
            "SigningAlgorithm": signing_algorithm,
        },
    )


async def verify(
    hub,
    ctx,
    key_id: str,
    message: bytes,
    signature: bytes,
    signing_algorithm: str,
    message_type: str = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Verifies a digital signature that was generated by the Sign operation.   Verification confirms that an authorized user signed the message with the specified CMK and signing algorithm, and the message hasn't changed since it was signed. If the signature is verified, the value of the SignatureValid field in the response is True. If the signature verification fails, the Verify operation fails with an KMSInvalidSignatureException exception. A digital signature is generated by using the private key in an asymmetric CMK. The signature is verified by using the public key in the same asymmetric CMK. For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. To verify a digital signature, you can use the Verify operation. Specify the same asymmetric CMK, message, and signing algorithm that were used to produce the signature. You can also verify the digital signature by using the public key of the CMK outside of AWS KMS. Use the GetPublicKey operation to download the public key in the asymmetric CMK and then use the public key to verify the signature outside of AWS KMS. The advantage of using the Verify operation is that it is performed within AWS KMS. As a result, it's easy to call, the operation is performed within the FIPS boundary, it is logged in AWS CloudTrail, and you can use key policy and IAM policy to determine who is authorized to use the CMK to verify signatures. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.   Required permissions: kms:Verify (key policy)  Related operations: Sign

    Args:
        key_id(str): Identifies the asymmetric CMK that will be used to verify the signature. This must be the same CMK that was used to generate the signature. If you specify a different CMK, the signature verification fails. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        message(bytes): Specifies the message that was signed. You can submit a raw message of up to 4096 bytes, or a hash digest of the message. If you submit a digest, use the MessageType parameter with a value of DIGEST. If the message specified here is different from the message that was signed, the signature verification fails. A message and its hash digest are considered to be the same message.
        message_type(str, optional): Tells AWS KMS whether the value of the Message parameter is a message or message digest. The default value, RAW, indicates a message. To indicate a message digest, enter DIGEST.  Use the DIGEST value only when the value of the Message parameter is a message digest. If you use the DIGEST value with a raw message, the security of the verification operation can be compromised. . Defaults to None.
        signature(bytes): The signature that the Sign operation generated.
        signing_algorithm(str): The signing algorithm that was used to sign the message. If you submit a different algorithm, the signature verification fails.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.init.verify(
                ctx, key_id=value, message=value, signature=value, signing_algorithm=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.init.verify key_id=value, message=value, signature=value, signing_algorithm=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="verify",
        op_kwargs={
            "KeyId": key_id,
            "Message": message,
            "MessageType": message_type,
            "Signature": signature,
            "SigningAlgorithm": signing_algorithm,
            "GrantTokens": grant_tokens,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub, ctx, account_ids: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the optimization findings for an account. It returns the number of:   Amazon EC2 instances in an account that are Underprovisioned, Overprovisioned, or Optimized.   Auto Scaling groups in an account that are NotOptimized, or Optimized.   Amazon EBS volumes in an account that are NotOptimized, or Optimized.   Lambda functions in an account that are NotOptimized, or Optimized.

    Args:
        account_ids(List, optional): The ID of the AWS account for which to return recommendation summaries. If your account is the management account of an organization, use this parameter to specify the member account for which you want to return recommendation summaries. Only one account ID can be specified per request. Defaults to None.
        next_token(str, optional): The token to advance to the next page of recommendation summaries. Defaults to None.
        max_results(int, optional): The maximum number of recommendation summaries to return with a single request. To retrieve the remaining results, make another request with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.recommendation.summary.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.recommendation.summary.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="get_recommendation_summaries",
        op_kwargs={
            "accountIds": account_ids,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, job_name: str, job_run_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Stops one or more job runs for a specified job definition.

    Args:
        job_name(str): The name of the job definition for which to stop job runs.
        job_run_ids(List): A list of the JobRunIds that should be stopped for that job definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.stop_job_run.batch(ctx, job_name=value, job_run_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.stop_job_run.batch job_name=value, job_run_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_stop_job_run",
        op_kwargs={"JobName": job_name, "JobRunIds": job_run_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, organization_id: str, resource_id: str, entity_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a member from the resource's set of delegates.

    Args:
        organization_id(str): The identifier for the organization under which the resource exists.
        resource_id(str): The identifier of the resource from which delegates' set members are removed. .
        entity_id(str): The identifier for the member (user, group) to be removed from the resource's delegates.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.delegate.from_resource.disassociate(
                ctx, organization_id=value, resource_id=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.delegate.from_resource.disassociate organization_id=value, resource_id=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="disassociate_delegate_from_resource",
        op_kwargs={
            "OrganizationId": organization_id,
            "ResourceId": resource_id,
            "EntityId": entity_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, global_endpoint_token_version: str) -> None:
    r"""
    **Autogenerated function**

    Sets the specified version of the global endpoint token as the token version used for the account. By default, Security Token Service (STS) is available as a global service, and all STS requests go to a single endpoint at https://sts.amazonaws.com. Amazon Web Services recommends using Regional STS endpoints to reduce latency, build in redundancy, and increase session token availability. For information about Regional endpoints for STS, see Security Token Service endpoints and quotas in the Amazon Web Services General Reference. If you make an STS call to the global endpoint, the resulting session tokens might be valid in some Regions but not others. It depends on the version that is set in this operation. Version 1 tokens are valid only in Regions that are available by default. These tokens do not work in manually enabled Regions, such as Asia Pacific (Hong Kong). Version 2 tokens are valid in all Regions. However, version 2 tokens are longer and might affect systems where you temporarily store tokens. For information, see Activating and deactivating STS in an Region in the IAM User Guide. To view the current session token version, see the GlobalEndpointTokenVersion entry in the response of the GetAccountSummary operation.

    Args:
        global_endpoint_token_version(str): The version of the global endpoint token. Version 1 tokens are valid only in Regions that are available by default. These tokens do not work in manually enabled Regions, such as Asia Pacific (Hong Kong). Version 2 tokens are valid in all Regions. However, version 2 tokens are longer and might affect systems where you temporarily store tokens. For information, see Activating and deactivating STS in an Region in the IAM User Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.security_token_service_preference.set(
                ctx, global_endpoint_token_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.security_token_service_preference.set global_endpoint_token_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="set_security_token_service_preferences",
        op_kwargs={"GlobalEndpointTokenVersion": global_endpoint_token_version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, rule_name: str, topic_rule_payload: Dict, tags: str = None
) -> None:
    r"""
    **Autogenerated function**

    Creates a rule. Creating rules is an administrator-level action. Any user who has permission to create rules will be able to access data processed by the rule.

    Args:
        rule_name(str): The name of the rule.
        topic_rule_payload(Dict): The rule payload.
        tags(str, optional): Metadata which can be used to manage the topic rule.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: --tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.create(
                ctx, rule_name=value, topic_rule_payload=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.create rule_name=value, topic_rule_payload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_topic_rule",
        op_kwargs={
            "ruleName": rule_name,
            "topicRulePayload": topic_rule_payload,
            "tags": tags,
        },
    )


async def delete(hub, ctx, rule_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the rule.

    Args:
        rule_name(str): The name of the rule.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.delete(ctx, rule_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.delete rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_topic_rule",
        op_kwargs={"ruleName": rule_name},
    )


async def disable(hub, ctx, rule_name: str) -> None:
    r"""
    **Autogenerated function**

    Disables the rule.

    Args:
        rule_name(str): The name of the rule to disable.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.disable(ctx, rule_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.disable rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="disable_topic_rule",
        op_kwargs={"ruleName": rule_name},
    )


async def enable(hub, ctx, rule_name: str) -> None:
    r"""
    **Autogenerated function**

    Enables the rule.

    Args:
        rule_name(str): The name of the topic rule to enable.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.enable(ctx, rule_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.enable rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="enable_topic_rule",
        op_kwargs={"ruleName": rule_name},
    )


async def get(hub, ctx, rule_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the rule.

    Args:
        rule_name(str): The name of the rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.get(ctx, rule_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.get rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_topic_rule",
        op_kwargs={"ruleName": rule_name},
    )


async def list_all(
    hub,
    ctx,
    topic: str = None,
    max_results: int = None,
    next_token: str = None,
    rule_disabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the rules for the specific topic.

    Args:
        topic(str, optional): The topic. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        rule_disabled(bool, optional): Specifies whether the rule is disabled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_topic_rules",
        op_kwargs={
            "topic": topic,
            "maxResults": max_results,
            "nextToken": next_token,
            "ruleDisabled": rule_disabled,
        },
    )


async def replace(hub, ctx, rule_name: str, topic_rule_payload: Dict) -> None:
    r"""
    **Autogenerated function**

    Replaces the rule. You must specify all parameters for the new rule. Creating rules is an administrator-level action. Any user who has permission to create rules will be able to access data processed by the rule.

    Args:
        rule_name(str): The name of the rule.
        topic_rule_payload(Dict): The rule payload.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.topic_rule.init.replace(
                ctx, rule_name=value, topic_rule_payload=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.topic_rule.init.replace rule_name=value, topic_rule_payload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="replace_topic_rule",
        op_kwargs={"ruleName": rule_name, "topicRulePayload": topic_rule_payload},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, pipeline_execution_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the details of a pipeline execution.

    Args:
        pipeline_execution_arn(str): The Amazon Resource Name (ARN) of the pipeline execution.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.init.describe(
                ctx, pipeline_execution_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.init.describe pipeline_execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_pipeline_execution",
        op_kwargs={"PipelineExecutionArn": pipeline_execution_arn},
    )


async def list_all(
    hub,
    ctx,
    pipeline_name: str,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the pipeline executions.

    Args:
        pipeline_name(str): The name of the pipeline.
        created_after(str, optional): A filter that returns the pipeline executions that were created after a specified time. Defaults to None.
        created_before(str, optional): A filter that returns the pipeline executions that were created before a specified time. Defaults to None.
        sort_by(str, optional): The field by which to sort results. The default is CreatedTime. Defaults to None.
        sort_order(str, optional): The sort order for results. Defaults to None.
        next_token(str, optional): If the result of the previous ListPipelineExecutions request was truncated, the response includes a NextToken. To retrieve the next set of pipeline executions, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of pipeline executions to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.init.list_all(
                ctx, pipeline_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.init.list_all pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_pipeline_executions",
        op_kwargs={
            "PipelineName": pipeline_name,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    pipeline_name: str,
    client_request_token: str,
    pipeline_execution_display_name: str = None,
    pipeline_parameters: List = None,
    pipeline_execution_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a pipeline execution.

    Args:
        pipeline_name(str): The name of the pipeline.
        pipeline_execution_display_name(str, optional): The display name of the pipeline execution. Defaults to None.
        pipeline_parameters(List, optional): Contains a list of pipeline parameters. This list can be empty. . Defaults to None.
        pipeline_execution_description(str, optional): The description of the pipeline execution. Defaults to None.
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.init.start(
                ctx, pipeline_name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.init.start pipeline_name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="start_pipeline_execution",
        op_kwargs={
            "PipelineName": pipeline_name,
            "PipelineExecutionDisplayName": pipeline_execution_display_name,
            "PipelineParameters": pipeline_parameters,
            "PipelineExecutionDescription": pipeline_execution_description,
            "ClientRequestToken": client_request_token,
        },
    )


async def stop(
    hub, ctx, pipeline_execution_arn: str, client_request_token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Stops a pipeline execution. A pipeline execution won't stop while a callback step is running. When you call StopPipelineExecution on a pipeline execution with a running callback step, SageMaker Pipelines sends an additional Amazon SQS message to the specified SQS queue. The body of the SQS message contains a "Status" field which is set to "Stopping". You should add logic to your Amazon SQS message consumer to take any needed action (for example, resource cleanup) upon receipt of the message followed by a call to SendPipelineExecutionStepSuccess or SendPipelineExecutionStepFailure. Only when SageMaker Pipelines receives one of these calls will it stop the pipeline execution.

    Args:
        pipeline_execution_arn(str): The Amazon Resource Name (ARN) of the pipeline execution.
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.init.stop(
                ctx, pipeline_execution_arn=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.init.stop pipeline_execution_arn=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_pipeline_execution",
        op_kwargs={
            "PipelineExecutionArn": pipeline_execution_arn,
            "ClientRequestToken": client_request_token,
        },
    )


async def update(
    hub,
    ctx,
    pipeline_execution_arn: str,
    pipeline_execution_description: str = None,
    pipeline_execution_display_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a pipeline execution.

    Args:
        pipeline_execution_arn(str): The Amazon Resource Name (ARN) of the pipeline execution.
        pipeline_execution_description(str, optional): The description of the pipeline execution. Defaults to None.
        pipeline_execution_display_name(str, optional): The display name of the pipeline execution. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.init.update(
                ctx, pipeline_execution_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.init.update pipeline_execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_pipeline_execution",
        op_kwargs={
            "PipelineExecutionArn": pipeline_execution_arn,
            "PipelineExecutionDescription": pipeline_execution_description,
            "PipelineExecutionDisplayName": pipeline_execution_display_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_snapshot_identifier: str,
    target_db_snapshot_identifier: str,
    kms_key_id: str = None,
    tags: List = None,
    copy_tags: bool = None,
    pre_signed_url: str = None,
    option_group_name: str = None,
    target_custom_availability_zone: str = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified DB snapshot. The source DB snapshot must be in the available state. You can copy a snapshot from one Amazon Web Services Region to another. In that case, the Amazon Web Services Region where you call the CopyDBSnapshot action is the destination Amazon Web Services Region for the DB snapshot copy.  For more information about copying snapshots, see Copying a DB Snapshot in the Amazon RDS User Guide.

    Args:
        source_db_snapshot_identifier(str): The identifier for the source DB snapshot. If the source snapshot is in the same Amazon Web Services Region as the copy, specify a valid DB snapshot identifier. For example, you might specify rds:mysql-instance1-snapshot-20130805.  If the source snapshot is in a different Amazon Web Services Region than the copy, specify a valid DB snapshot ARN. For example, you might specify arn:aws:rds:us-west-2:123456789012:snapshot:mysql-instance1-snapshot-20130805.  If you are copying from a shared manual DB snapshot, this parameter must be the Amazon Resource Name (ARN) of the shared DB snapshot.  If you are copying an encrypted snapshot this parameter must be in the ARN format for the source Amazon Web Services Region, and must match the SourceDBSnapshotIdentifier in the PreSignedUrl parameter.  Constraints:   Must specify a valid system snapshot in the "available" state.   Example: rds:mydb-2012-04-02-00-01  Example: arn:aws:rds:us-west-2:123456789012:snapshot:mysql-instance1-snapshot-20130805 .
        target_db_snapshot_identifier(str): The identifier for the copy of the snapshot.  Constraints:   Can't be null, empty, or blank   Must contain from 1 to 255 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: my-db-snapshot .
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier for an encrypted DB snapshot. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK).  If you copy an encrypted DB snapshot from your Amazon Web Services account, you can specify a value for this parameter to encrypt the copy with a new Amazon Web Services KMS CMK. If you don't specify a value for this parameter, then the copy of the DB snapshot is encrypted with the same Amazon Web Services KMS key as the source DB snapshot.  If you copy an encrypted DB snapshot that is shared from another Amazon Web Services account, then you must specify a value for this parameter.  If you specify this parameter when you copy an unencrypted snapshot, the copy is encrypted.  If you copy an encrypted snapshot to a different Amazon Web Services Region, then you must specify a Amazon Web Services KMS key identifier for the destination Amazon Web Services Region. Amazon Web Services KMS CMKs are specific to the Amazon Web Services Region that they are created in, and you can't use CMKs from one Amazon Web Services Region in another Amazon Web Services Region. . Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        copy_tags(bool, optional): A value that indicates whether to copy all tags from the source DB snapshot to the target DB snapshot. By default, tags are not copied. Defaults to None.
        pre_signed_url(str, optional): The URL that contains a Signature Version 4 signed request for the CopyDBSnapshot API action in the source Amazon Web Services Region that contains the source DB snapshot to copy.  You must specify this parameter when you copy an encrypted DB snapshot from another Amazon Web Services Region by using the Amazon RDS API. Don't specify PreSignedUrl when you are copying an encrypted DB snapshot in the same Amazon Web Services Region. The presigned URL must be a valid request for the CopyDBSnapshot API action that can be executed in the source Amazon Web Services Region that contains the encrypted DB snapshot to be copied. The presigned URL request must contain the following parameter values:     DestinationRegion - The Amazon Web Services Region that the encrypted DB snapshot is copied to. This Amazon Web Services Region is the same one where the CopyDBSnapshot action is called that contains this presigned URL.  For example, if you copy an encrypted DB snapshot from the us-west-2 Amazon Web Services Region to the us-east-1 Amazon Web Services Region, then you call the CopyDBSnapshot action in the us-east-1 Amazon Web Services Region and provide a presigned URL that contains a call to the CopyDBSnapshot action in the us-west-2 Amazon Web Services Region. For this example, the DestinationRegion in the presigned URL must be set to the us-east-1 Amazon Web Services Region.     KmsKeyId - The Amazon Web Services KMS key identifier for the customer master key (CMK) to use to encrypt the copy of the DB snapshot in the destination Amazon Web Services Region. This is the same identifier for both the CopyDBSnapshot action that is called in the destination Amazon Web Services Region, and the action contained in the presigned URL.     SourceDBSnapshotIdentifier - The DB snapshot identifier for the encrypted snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB snapshot from the us-west-2 Amazon Web Services Region, then your SourceDBSnapshotIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:snapshot:mysql-instance1-snapshot-20161115.    To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process.   If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a pre-signed URL that is a valid request for the operation that can be executed in the source Amazon Web Services Region. . Defaults to None.
        option_group_name(str, optional): The name of an option group to associate with the copy of the snapshot. Specify this option if you are copying a snapshot from one Amazon Web Services Region to another, and your DB instance uses a nondefault option group. If your source DB instance uses Transparent Data Encryption for Oracle or Microsoft SQL Server, you must specify this option when copying across Amazon Web Services Regions. For more information, see Option group considerations in the Amazon RDS User Guide. . Defaults to None.
        target_custom_availability_zone(str, optional): The external custom Availability Zone (CAZ) identifier for the target CAZ. Example: rds-caz-aiqhTgQv. Defaults to None.
        source_region(str, optional): The ID of the region that contains the snapshot to be copied. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.init.copy(
                ctx, source_db_snapshot_identifier=value, target_db_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.init.copy source_db_snapshot_identifier=value, target_db_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="copy_db_snapshot",
        op_kwargs={
            "SourceDBSnapshotIdentifier": source_db_snapshot_identifier,
            "TargetDBSnapshotIdentifier": target_db_snapshot_identifier,
            "KmsKeyId": kms_key_id,
            "Tags": tags,
            "CopyTags": copy_tags,
            "PreSignedUrl": pre_signed_url,
            "OptionGroupName": option_group_name,
            "TargetCustomAvailabilityZone": target_custom_availability_zone,
            "SourceRegion": source_region,
        },
    )


async def create(
    hub,
    ctx,
    db_snapshot_identifier: str,
    db_instance_identifier: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a DB instance. The source DB instance must be in the available or storage-optimization state.

    Args:
        db_snapshot_identifier(str): The identifier for the DB snapshot. Constraints:   Can't be null, empty, or blank   Must contain from 1 to 255 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: my-snapshot-id .
        db_instance_identifier(str): The identifier of the DB instance that you want to create the snapshot of. Constraints:   Must match the identifier of an existing DBInstance.  .
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.init.create(
                ctx, db_snapshot_identifier=value, db_instance_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.init.create db_snapshot_identifier=value, db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_snapshot",
        op_kwargs={
            "DBSnapshotIdentifier": db_snapshot_identifier,
            "DBInstanceIdentifier": db_instance_identifier,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_snapshot_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a DB snapshot. If the snapshot is being copied, the copy operation is terminated.  The DB snapshot must be in the available state to be deleted.

    Args:
        db_snapshot_identifier(str): The DB snapshot identifier. Constraints: Must be the name of an existing DB snapshot in the available state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.init.delete(ctx, db_snapshot_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.init.delete db_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_snapshot",
        op_kwargs={"DBSnapshotIdentifier": db_snapshot_identifier},
    )


async def describe_all(
    hub,
    ctx,
    db_instance_identifier: str = None,
    db_snapshot_identifier: str = None,
    snapshot_type: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    include_shared: bool = None,
    include_public: bool = None,
    dbi_resource_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DB snapshots. This API action supports pagination.

    Args:
        db_instance_identifier(str, optional): The ID of the DB instance to retrieve the list of DB snapshots for. This parameter can't be used in conjunction with DBSnapshotIdentifier. This parameter isn't case-sensitive.  Constraints:   If supplied, must match the identifier of an existing DBInstance.  . Defaults to None.
        db_snapshot_identifier(str, optional):  A specific DB snapshot identifier to describe. This parameter can't be used in conjunction with DBInstanceIdentifier. This value is stored as a lowercase string.  Constraints:   If supplied, must match the identifier of an existing DBSnapshot.   If this identifier is for an automated snapshot, the SnapshotType parameter must also be specified.  . Defaults to None.
        snapshot_type(str, optional): The type of snapshots to be returned. You can specify one of the following values:    automated - Return all DB snapshots that have been automatically taken by Amazon RDS for my Amazon Web Services account.    manual - Return all DB snapshots that have been taken by my Amazon Web Services account.    shared - Return all manual DB snapshots that have been shared to my Amazon Web Services account.    public - Return all DB snapshots that have been marked as public.    awsbackup - Return the DB snapshots managed by the Amazon Web Services Backup service. For information about Amazon Web Services Backup, see the  Amazon Web Services Backup Developer Guide.   The awsbackup type does not apply to Aurora.   If you don't specify a SnapshotType value, then both automated and manual snapshots are returned. Shared and public DB snapshots are not included in the returned results by default. You can include shared snapshots with these results by enabling the IncludeShared parameter. You can include public snapshots with these results by enabling the IncludePublic parameter. The IncludeShared and IncludePublic parameters don't apply for SnapshotType values of manual or automated. The IncludePublic parameter doesn't apply when SnapshotType is set to shared. The IncludeShared parameter doesn't apply when SnapshotType is set to public. Defaults to None.
        filters(List, optional): A filter that specifies one or more DB snapshots to describe. Supported filters:    db-instance-id - Accepts DB instance identifiers and DB instance Amazon Resource Names (ARNs).    db-snapshot-id - Accepts DB snapshot identifiers.    dbi-resource-id - Accepts identifiers of source DB instances.    snapshot-type - Accepts types of DB snapshots.    engine - Accepts names of database engines.  . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBSnapshots request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        include_shared(bool, optional): A value that indicates whether to include shared manual DB cluster snapshots from other Amazon Web Services accounts that this Amazon Web Services account has been given permission to copy or restore. By default, these snapshots are not included. You can give an Amazon Web Services account permission to restore a manual DB snapshot from another Amazon Web Services account by using the ModifyDBSnapshotAttribute API action. Defaults to None.
        include_public(bool, optional): A value that indicates whether to include manual DB cluster snapshots that are public and can be copied or restored by any Amazon Web Services account. By default, the public snapshots are not included. You can share a manual DB snapshot as public by using the ModifyDBSnapshotAttribute API. Defaults to None.
        dbi_resource_id(str, optional): A specific DB resource ID to describe. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_snapshots",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "DBSnapshotIdentifier": db_snapshot_identifier,
            "SnapshotType": snapshot_type,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "IncludeShared": include_shared,
            "IncludePublic": include_public,
            "DbiResourceId": dbi_resource_id,
        },
    )


async def modify(
    hub,
    ctx,
    db_snapshot_identifier: str,
    engine_version: str = None,
    option_group_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a manual DB snapshot with a new engine version. The snapshot can be encrypted or unencrypted, but not shared or public.  Amazon RDS supports upgrading DB snapshots for MySQL, Oracle, and PostgreSQL.

    Args:
        db_snapshot_identifier(str): The identifier of the DB snapshot to modify.
        engine_version(str, optional): The engine version to upgrade the DB snapshot to.  The following are the database engines and engine versions that are available when you upgrade a DB snapshot.   MySQL     5.5.46 (supported for 5.1 DB snapshots)    Oracle     12.1.0.2.v8 (supported for 12.1.0.1 DB snapshots)    11.2.0.4.v12 (supported for 11.2.0.2 DB snapshots)    11.2.0.4.v11 (supported for 11.2.0.3 DB snapshots)    PostgreSQL  For the list of engine versions that are available for upgrading a DB snapshot, see  Upgrading the PostgreSQL DB Engine for Amazon RDS. . Defaults to None.
        option_group_name(str, optional): The option group to identify with the upgraded DB snapshot.  You can specify this parameter when you upgrade an Oracle DB snapshot. The same option group considerations apply when upgrading a DB snapshot as when upgrading a DB instance. For more information, see Option group considerations in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.init.modify(ctx, db_snapshot_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.init.modify db_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_db_snapshot",
        op_kwargs={
            "DBSnapshotIdentifier": db_snapshot_identifier,
            "EngineVersion": engine_version,
            "OptionGroupName": option_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    certificate_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of certificate authority (CA) certificates provided by Amazon DocumentDB for this account.

    Args:
        certificate_identifier(str, optional): The user-supplied certificate identifier. If this parameter is specified, information for only the specified certificate is returned. If this parameter is omitted, a list of up to MaxRecords certificates is returned. This parameter is not case sensitive. Constraints   Must match an existing CertificateIdentifier.  . Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints:   Minimum: 20   Maximum: 100  . Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeCertificates request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.certificate.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.certificate.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_certificates",
        op_kwargs={
            "CertificateIdentifier": certificate_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    secret_id: str,
    version_stage: str,
    remove_from_version_id: str = None,
    move_to_version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the staging labels attached to a version of a secret. Staging labels are used to track a version as it progresses through the secret rotation process. You can attach a staging label to only one version of a secret at a time. If a staging label to be added is already attached to another version, then it is moved--removed from the other version first and then attached to this one. For more information about staging labels, see Staging Labels in the Amazon Web Services Secrets Manager User Guide.  The staging labels that you specify in the VersionStage parameter are added to the existing list of staging labels--they don't replace it. You can move the AWSCURRENT staging label to this version by including it in this call.  Whenever you move AWSCURRENT, Secrets Manager automatically moves the label AWSPREVIOUS to the version that AWSCURRENT was removed from.  If this action results in the last label being removed from a version, then the version is considered to be 'deprecated' and can be deleted by Secrets Manager.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:UpdateSecretVersionStage    Related operations    To get the list of staging labels that are currently associated with a version of a secret, use  DescribeSecret  and examine the SecretVersionsToStages response value.

    Args:
        secret_id(str): Specifies the secret with the version with the list of staging labels you want to modify. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        version_stage(str): The staging label to add to this version.
        remove_from_version_id(str, optional): Specifies the secret version ID of the version that the staging label is to be removed from. If the staging label you are trying to attach to one version is already attached to a different version, then you must include this parameter and specify the version that the label is to be removed from. If the label is attached and you either do not specify this parameter, or the version ID does not match, then the operation fails. Defaults to None.
        move_to_version_id(str, optional): (Optional) The secret version ID that you want to add the staging label. If you want to remove a label from a version, then do not specify this parameter. If the staging label is already attached to a different version of the secret, then you must also specify the RemoveFromVersionId parameter. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.secret.version.stage.update(
                ctx, secret_id=value, version_stage=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.secret.version.stage.update secret_id=value, version_stage=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="update_secret_version_stage",
        op_kwargs={
            "SecretId": secret_id,
            "VersionStage": version_stage,
            "RemoveFromVersionId": remove_from_version_id,
            "MoveToVersionId": move_to_version_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub, ctx, repository_name: str, image_id: Dict, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an image vulnerability scan. An image scan can only be started once per day on an individual image. This limit includes if an image was scanned on initial push. For more information, see Image Scanning in the Amazon Elastic Container Registry User Guide.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to start an image scan request. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository that contains the images to scan.
        image_id(Dict): An object with identifying information for an Amazon ECR image.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.scan.init.start(
                ctx, repository_name=value, image_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.scan.init.start repository_name=value, image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="start_image_scan",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageId": image_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, application_id: str, endpoint_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an endpoint from an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        endpoint_id(str): The unique identifier for the endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.endpoint.init.delete(
                ctx, application_id=value, endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.endpoint.init.delete application_id=value, endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_endpoint",
        op_kwargs={"ApplicationId": application_id, "EndpointId": endpoint_id},
    )


async def get(hub, ctx, application_id: str, endpoint_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the settings and attributes of a specific endpoint for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        endpoint_id(str): The unique identifier for the endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.endpoint.init.get(
                ctx, application_id=value, endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.endpoint.init.get application_id=value, endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_endpoint",
        op_kwargs={"ApplicationId": application_id, "EndpointId": endpoint_id},
    )


async def update(
    hub, ctx, application_id: str, endpoint_id: str, endpoint_request: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new endpoint for an application or updates the settings and attributes of an existing endpoint for an application. You can also use this operation to define custom attributes for an endpoint. If an update includes one or more values for a custom attribute, Amazon Pinpoint replaces (overwrites) any existing values with the new values.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        endpoint_id(str): The unique identifier for the endpoint.
        endpoint_request(Dict): Specifies the channel type and other settings for an endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.endpoint.init.update(
                ctx, application_id=value, endpoint_id=value, endpoint_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.endpoint.init.update application_id=value, endpoint_id=value, endpoint_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_endpoint",
        op_kwargs={
            "ApplicationId": application_id,
            "EndpointId": endpoint_id,
            "EndpointRequest": endpoint_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, gateway_id: str, capability_namespace: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a gateway capability configuration. Each gateway capability defines data sources for a gateway. A capability configuration can contain multiple data source configurations. If you define OPC-UA sources for a gateway in the IoT SiteWise console, all of your OPC-UA sources are stored in one capability configuration. To list all capability configurations for a gateway, use DescribeGateway.

    Args:
        gateway_id(str): The ID of the gateway that defines the capability configuration.
        capability_namespace(str): The namespace of the capability configuration. For example, if you configure OPC-UA sources from the IoT SiteWise console, your OPC-UA capability configuration has the namespace iotsitewise:opcuacollector:version, where version is a number such as 1.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.capability_configuration.describe(
                ctx, gateway_id=value, capability_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.capability_configuration.describe gateway_id=value, capability_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_gateway_capability_configuration",
        op_kwargs={
            "gatewayId": gateway_id,
            "capabilityNamespace": capability_namespace,
        },
    )


async def update(
    hub, ctx, gateway_id: str, capability_namespace: str, capability_configuration: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a gateway capability configuration or defines a new capability configuration. Each gateway capability defines data sources for a gateway. A capability configuration can contain multiple data source configurations. If you define OPC-UA sources for a gateway in the IoT SiteWise console, all of your OPC-UA sources are stored in one capability configuration. To list all capability configurations for a gateway, use DescribeGateway.

    Args:
        gateway_id(str): The ID of the gateway to be updated.
        capability_namespace(str): The namespace of the gateway capability configuration to be updated. For example, if you configure OPC-UA sources from the IoT SiteWise console, your OPC-UA capability configuration has the namespace iotsitewise:opcuacollector:version, where version is a number such as 1.
        capability_configuration(str): The JSON document that defines the configuration for the gateway capability. For more information, see Configuring data sources (CLI) in the IoT SiteWise User Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.capability_configuration.update(
                ctx, gateway_id=value, capability_namespace=value, capability_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.capability_configuration.update gateway_id=value, capability_namespace=value, capability_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="update_gateway_capability_configuration",
        op_kwargs={
            "gatewayId": gateway_id,
            "capabilityNamespace": capability_namespace,
            "capabilityConfiguration": capability_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The product view identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.view.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.view.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_product_view",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    group_by: str,
    finding_criteria: Dict = None,
    size: int = None,
    sort_criteria: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Retrieves (queries) aggregated statistical data about findings.

    Args:
        finding_criteria(Dict, optional): The criteria to use to filter the query results. Defaults to None.
        group_by(str): The finding property to use to group the query results. Valid values are: classificationDetails.jobId - The unique identifier for the classification job that produced the finding. resourcesAffected.s3Bucket.name - The name of the S3 bucket that the finding applies to. severity.description - The severity level of the finding, such as High or Medium. type - The type of finding, such as Policy:IAMUser/S3BucketPublic and SensitiveData:S3Object/Personal.
        size(int, optional): The maximum number of items to include in each page of the response. Defaults to None.
        sort_criteria(Dict, optional): The criteria to use to sort the query results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.statistic.get_all(ctx, group_by=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.statistic.get_all group_by=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_finding_statistics",
        op_kwargs={
            "findingCriteria": finding_criteria,
            "groupBy": group_by,
            "size": size,
            "sortCriteria": sort_criteria,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, job_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets face detection results for a Amazon Rekognition Video analysis started by StartFaceDetection. Face detection with Amazon Rekognition Video is an asynchronous operation. You start face detection by calling StartFaceDetection which returns a job identifier (JobId). When the face detection operation finishes, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartFaceDetection. To get the results of the face detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetFaceDetection and pass the job identifier (JobId) from the initial call to StartFaceDetection.  GetFaceDetection returns an array of detected faces (Faces) sorted by the time the faces were detected.  Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetFaceDetection and populate the NextToken request parameter with the token value returned from the previous call to GetFaceDetection.

    Args:
        job_id(str): Unique identifier for the face detection job. The JobId is returned from StartFaceDetection.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there are more faces to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of faces. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.detection.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.detection.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_face_detection",
        op_kwargs={"JobId": job_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(
    hub,
    ctx,
    video: Dict,
    client_request_token: str = None,
    notification_channel: Dict = None,
    face_attributes: str = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts asynchronous detection of faces in a stored video. Amazon Rekognition Video can detect faces in a video stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartFaceDetection returns a job identifier (JobId) that you use to get the results of the operation. When face detection is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the results of the face detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetFaceDetection and pass the job identifier (JobId) from the initial call to StartFaceDetection. For more information, see Detecting Faces in a Stored Video in the Amazon Rekognition Developer Guide.

    Args:
        video(Dict): The video in which you want to detect faces. The video must be stored in an Amazon S3 bucket.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartFaceDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        notification_channel(Dict, optional): The ARN of the Amazon SNS topic to which you want Amazon Rekognition Video to publish the completion status of the face detection operation. Defaults to None.
        face_attributes(str, optional): The face attributes you want returned.  DEFAULT - The following subset of facial attributes are returned: BoundingBox, Confidence, Pose, Quality and Landmarks.   ALL - All facial attributes are returned. Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.detection.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.detection.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_face_detection",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "FaceAttributes": face_attributes,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upload(
    hub,
    ctx,
    repository_name: str,
    upload_id: str,
    part_first_byte: int,
    part_last_byte: int,
    layer_part_blob: bytes,
    registry_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads an image layer part to Amazon ECR. When an image is pushed, each new image layer is uploaded in parts. The maximum size of each image layer part can be 20971520 bytes (or about 20MB). The UploadLayerPart API is called once per each new image layer part.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry to which you are uploading layer parts. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to which you are uploading layer parts.
        upload_id(str): The upload ID from a previous InitiateLayerUpload operation to associate with the layer part upload.
        part_first_byte(int): The position of the first byte of the layer part witin the overall image layer.
        part_last_byte(int): The position of the last byte of the layer part within the overall image layer.
        layer_part_blob(bytes): The base64-encoded layer part payload.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.layer.part.upload(
                ctx,
                repository_name=value,
                upload_id=value,
                part_first_byte=value,
                part_last_byte=value,
                layer_part_blob=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.layer.part.upload repository_name=value, upload_id=value, part_first_byte=value, part_last_byte=value, layer_part_blob=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="upload_layer_part",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "uploadId": upload_id,
            "partFirstByte": part_first_byte,
            "partLastByte": part_last_byte,
            "layerPartBlob": layer_part_blob,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, device_name: str, device_fleet_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Use to check if a device is registered with SageMaker Edge Manager.

    Args:
        device_name(str): The unique name of the device you want to get the registration status from.
        device_fleet_name(str): The name of the fleet that the device belongs to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_edge.device_registration.get(
                ctx, device_name=value, device_fleet_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_edge.device_registration.get device_name=value, device_fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-edge",
        operation="get_device_registration",
        op_kwargs={"DeviceName": device_name, "DeviceFleetName": device_fleet_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str = None,
    description: str = None,
    role_name: str = None,
    client_token: str = None,
    server_groups: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an application. An application consists of one or more server groups. Each server group contain one or more servers.

    Args:
        name(str, optional): The name of the new application. Defaults to None.
        description(str, optional): The description of the new application. Defaults to None.
        role_name(str, optional): The name of the service role in the customer's account to be used by AWS SMS. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of application creation. Defaults to None.
        server_groups(List, optional): The server groups to include in the application. Defaults to None.
        tags(List, optional): The tags to be associated with the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="create_app",
        op_kwargs={
            "name": name,
            "description": description,
            "roleName": role_name,
            "clientToken": client_token,
            "serverGroups": server_groups,
            "tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    app_id: str = None,
    force_stop_app_replication: bool = None,
    force_terminate_app: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified application. Optionally deletes the launched stack associated with the application and all AWS SMS replication jobs for servers in the application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.
        force_stop_app_replication(bool, optional): Indicates whether to stop all replication jobs corresponding to the servers in the application while deleting the application. Defaults to None.
        force_terminate_app(bool, optional): Indicates whether to terminate the stack corresponding to the application while deleting the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="delete_app",
        op_kwargs={
            "appId": app_id,
            "forceStopAppReplication": force_stop_app_replication,
            "forceTerminateApp": force_terminate_app,
        },
    )


async def get(hub, ctx, app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about the specified application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sms", operation="get_app", op_kwargs={"appId": app_id}
    )


async def launch(hub, ctx, app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Launches the specified application as a stack in AWS CloudFormation.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.launch(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.launch
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sms", operation="launch_app", op_kwargs={"appId": app_id}
    )


async def terminate(hub, ctx, app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Terminates the stack for the specified application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.terminate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.terminate
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sms", operation="terminate_app", op_kwargs={"appId": app_id}
    )


async def update(
    hub,
    ctx,
    app_id: str = None,
    name: str = None,
    description: str = None,
    role_name: str = None,
    server_groups: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.
        name(str, optional): The new name of the application. Defaults to None.
        description(str, optional): The new description of the application. Defaults to None.
        role_name(str, optional): The name of the service role in the customer's account used by AWS SMS. Defaults to None.
        server_groups(List, optional): The server groups in the application to update. Defaults to None.
        tags(List, optional): The tags to associate with the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="update_app",
        op_kwargs={
            "appId": app_id,
            "name": name,
            "description": description,
            "roleName": role_name,
            "serverGroups": server_groups,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def tag(hub, ctx, resource: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Add tags to a CloudFront resource.

    Args:
        resource(str):  An ARN of a CloudFront resource.
        tags(Dict):  A complex type that contains zero or more Tag elements.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.resource.tag(ctx, resource=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.resource.tag resource=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="tag_resource",
        op_kwargs={"Resource": resource, "Tags": tags},
    )


async def untag(hub, ctx, resource: str, tag_keys: Dict) -> None:
    r"""
    **Autogenerated function**

    Remove tags from a CloudFront resource.

    Args:
        resource(str):  An ARN of a CloudFront resource.
        tag_keys(Dict):  A complex type that contains zero or more Tag key elements.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.resource.untag(ctx, resource=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.resource.untag resource=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="untag_resource",
        op_kwargs={"Resource": resource, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def register(
    hub,
    ctx,
    window_id: str,
    resource_type: str,
    targets: List,
    owner_information: str = None,
    name: str = None,
    description: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a target with a maintenance window.

    Args:
        window_id(str): The ID of the maintenance window the target should be registered with.
        resource_type(str): The type of target being registered with the maintenance window.
        targets(List): The targets to register with the maintenance window. In other words, the instances to run commands on when the maintenance window runs.  If a single maintenance window task is registered with multiple targets, its task invocations occur sequentially and not in parallel. If your task must run on multiple targets at the same time, register a task for each target individually and assign each task the same priority level.  You can specify targets using instance IDs, resource group names, or tags that have been applied to instances.  Example 1: Specify instance IDs  Key=InstanceIds,Values=instance-id-1,instance-id-2,instance-id-3    Example 2: Use tag key-pairs applied to instances  Key=tag:my-tag-key,Values=my-tag-value-1,my-tag-value-2    Example 3: Use tag-keys applied to instances  Key=tag-key,Values=my-tag-key-1,my-tag-key-2    Example 4: Use resource group names  Key=resource-groups:Name,Values=resource-group-name    Example 5: Use filters for resource group types  Key=resource-groups:ResourceTypeFilters,Values=resource-type-1,resource-type-2    For Key=resource-groups:ResourceTypeFilters, specify resource types in the following format  Key=resource-groups:ResourceTypeFilters,Values=AWS::EC2::INSTANCE,AWS::EC2::VPC    For more information about these examples formats, including the best use case for each one, see Examples: Register targets with a maintenance window in the Amazon Web Services Systems Manager User Guide.
        owner_information(str, optional): User-provided value that will be included in any Amazon CloudWatch Events events raised while running tasks for these targets in this maintenance window. Defaults to None.
        name(str, optional): An optional name for the target. Defaults to None.
        description(str, optional): An optional description for the target. Defaults to None.
        client_token(str, optional): User-provided idempotency token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.target.with_maintenance_window.register(
                ctx, window_id=value, resource_type=value, targets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.target.with_maintenance_window.register window_id=value, resource_type=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="register_target_with_maintenance_window",
        op_kwargs={
            "WindowId": window_id,
            "ResourceType": resource_type,
            "Targets": targets,
            "OwnerInformation": owner_information,
            "Name": name,
            "Description": description,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    launch_template_configs: List,
    target_capacity_specification: Dict,
    dry_run: bool = None,
    client_token: str = None,
    spot_options: Dict = None,
    on_demand_options: Dict = None,
    excess_capacity_termination_policy: str = None,
    terminate_instances_with_expiration: bool = None,
    type_: str = None,
    valid_from: str = None,
    valid_until: str = None,
    replace_unhealthy_instances: bool = None,
    tag_specifications: List = None,
    context: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Launches an EC2 Fleet. You can create a single EC2 Fleet that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. For more information, see Launching an EC2 Fleet in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        spot_options(Dict, optional): Describes the configuration of Spot Instances in an EC2 Fleet. Defaults to None.
        on_demand_options(Dict, optional): Describes the configuration of On-Demand Instances in an EC2 Fleet. Defaults to None.
        excess_capacity_termination_policy(str, optional): Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet. Defaults to None.
        launch_template_configs(List): The configuration for the EC2 Fleet.
        target_capacity_specification(Dict): The number of units to request.
        terminate_instances_with_expiration(bool, optional): Indicates whether running instances should be terminated when the EC2 Fleet expires. Defaults to None.
        type_(str, optional): The fleet type. The default value is maintain.    maintain - The EC2 Fleet places an asynchronous request for your desired capacity, and continues to maintain your desired Spot capacity by replenishing interrupted Spot Instances.    request - The EC2 Fleet places an asynchronous one-time request for your desired capacity, but does submit Spot requests in alternative capacity pools if Spot capacity is unavailable, and does not maintain Spot capacity if Spot Instances are interrupted.    instant - The EC2 Fleet places a synchronous one-time request for your desired capacity, and returns errors for any instances that could not be launched.   For more information, see EC2 Fleet request types in the Amazon EC2 User Guide. Defaults to None.
        valid_from(str, optional): The start date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately. Defaults to None.
        valid_until(str, optional): The end date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new EC2 Fleet requests are placed or able to fulfill the request. If no value is specified, the request remains until you cancel it. Defaults to None.
        replace_unhealthy_instances(bool, optional): Indicates whether EC2 Fleet should replace unhealthy Spot Instances. Supported only for fleets of type maintain. For more information, see EC2 Fleet health checks in the Amazon EC2 User Guide. Defaults to None.
        tag_specifications(List, optional): The key-value pair for tagging the EC2 Fleet request on creation. For more information, see Tagging your resources. If the fleet type is instant, specify a resource type of fleet to tag the fleet or instance to tag the instances at launch. If the fleet type is maintain or request, specify a resource type of fleet to tag the fleet. You cannot specify a resource type of instance. To tag instances at launch, specify the tags in a launch template. Defaults to None.
        context(str, optional): Reserved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.init.create(
                ctx, launch_template_configs=value, target_capacity_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.init.create launch_template_configs=value, target_capacity_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_fleet",
        op_kwargs={
            "DryRun": dry_run,
            "ClientToken": client_token,
            "SpotOptions": spot_options,
            "OnDemandOptions": on_demand_options,
            "ExcessCapacityTerminationPolicy": excess_capacity_termination_policy,
            "LaunchTemplateConfigs": launch_template_configs,
            "TargetCapacitySpecification": target_capacity_specification,
            "TerminateInstancesWithExpiration": terminate_instances_with_expiration,
            "Type": type_,
            "ValidFrom": valid_from,
            "ValidUntil": valid_until,
            "ReplaceUnhealthyInstances": replace_unhealthy_instances,
            "TagSpecifications": tag_specifications,
            "Context": context,
        },
    )


async def delete_multiple(
    hub, ctx, fleet_ids: List, terminate_instances: bool, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified EC2 Fleet. After you delete an EC2 Fleet, it launches no new instances. You must specify whether a deleted EC2 Fleet should also terminate its instances. If you choose to terminate the instances, the EC2 Fleet enters the deleted_terminating state. Otherwise, the EC2 Fleet enters the deleted_running state, and the instances continue to run until they are interrupted or you terminate them manually. For instant fleets, EC2 Fleet must terminate the instances when the fleet is deleted. A deleted instant fleet with running instances is not supported.  Restrictions    You can delete up to 25 instant fleets in a single request. If you exceed this number, no instant fleets are deleted and an error is returned. There is no restriction on the number of fleets of type maintain or request that can be deleted in a single request.   Up to 1000 instances can be terminated in a single request to delete instant fleets.   For more information, see Deleting an EC2 Fleet in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fleet_ids(List): The IDs of the EC2 Fleets.
        terminate_instances(bool): Indicates whether to terminate the instances when the EC2 Fleet is deleted. The default is to terminate the instances. To let the instances continue to run after the EC2 Fleet is deleted, specify NoTerminateInstances. Supported only for fleets of type maintain and request. For instant fleets, you cannot specify NoTerminateInstances. A deleted instant fleet with running instances is not supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.init.delete_multiple(
                ctx, fleet_ids=value, terminate_instances=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.init.delete_multiple fleet_ids=value, terminate_instances=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_fleets",
        op_kwargs={
            "DryRun": dry_run,
            "FleetIds": fleet_ids,
            "TerminateInstances": terminate_instances,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    max_results: int = None,
    next_token: str = None,
    fleet_ids: List = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified EC2 Fleets or all of your EC2 Fleets. For more information, see Monitoring your EC2 Fleet in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        fleet_ids(List, optional): The ID of the EC2 Fleets. Defaults to None.
        filters(List, optional): The filters.    activity-status - The progress of the EC2 Fleet ( error | pending-fulfillment | pending-termination | fulfilled).    excess-capacity-termination-policy - Indicates whether to terminate running instances if the target capacity is decreased below the current EC2 Fleet size (true | false).    fleet-state - The state of the EC2 Fleet (submitted | active | deleted | failed | deleted-running | deleted-terminating | modifying).    replace-unhealthy-instances - Indicates whether EC2 Fleet should replace unhealthy instances (true | false).    type - The type of request (instant | request | maintain).  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fleets",
        op_kwargs={
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
            "FleetIds": fleet_ids,
            "Filters": filters,
        },
    )


async def modify(
    hub,
    ctx,
    fleet_id: str,
    dry_run: bool = None,
    excess_capacity_termination_policy: str = None,
    launch_template_configs: List = None,
    target_capacity_specification: Dict = None,
    context: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified EC2 Fleet. You can only modify an EC2 Fleet request of type maintain. While the EC2 Fleet is being modified, it is in the modifying state. To scale up your EC2 Fleet, increase its target capacity. The EC2 Fleet launches the additional Spot Instances according to the allocation strategy for the EC2 Fleet request. If the allocation strategy is lowest-price, the EC2 Fleet launches instances using the Spot Instance pool with the lowest price. If the allocation strategy is diversified, the EC2 Fleet distributes the instances across the Spot Instance pools. If the allocation strategy is capacity-optimized, EC2 Fleet launches instances from Spot Instance pools with optimal capacity for the number of instances that are launching. To scale down your EC2 Fleet, decrease its target capacity. First, the EC2 Fleet cancels any open requests that exceed the new target capacity. You can request that the EC2 Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is lowest-price, the EC2 Fleet terminates the instances with the highest price per unit. If the allocation strategy is capacity-optimized, the EC2 Fleet terminates the instances in the Spot Instance pools that have the least available Spot Instance capacity. If the allocation strategy is diversified, the EC2 Fleet terminates instances across the Spot Instance pools. Alternatively, you can request that the EC2 Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually. If you are finished with your EC2 Fleet for now, but will use it again later, you can set the target capacity to 0.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        excess_capacity_termination_policy(str, optional): Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet. Defaults to None.
        launch_template_configs(List, optional): The launch template and overrides. Defaults to None.
        fleet_id(str): The ID of the EC2 Fleet.
        target_capacity_specification(Dict, optional): The size of the EC2 Fleet. Defaults to None.
        context(str, optional): Reserved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.init.modify(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.init.modify fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_fleet",
        op_kwargs={
            "DryRun": dry_run,
            "ExcessCapacityTerminationPolicy": excess_capacity_termination_policy,
            "LaunchTemplateConfigs": launch_template_configs,
            "FleetId": fleet_id,
            "TargetCapacitySpecification": target_capacity_specification,
            "Context": context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, environment_id: str, user_arn: str, permissions: str
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an environment member to an Cloud9 development environment.

    Args:
        environment_id(str): The ID of the environment that contains the environment member you want to add.
        user_arn(str): The Amazon Resource Name (ARN) of the environment member you want to add.
        permissions(str): The type of environment member permissions you want to associate with this environment member. Available values include:    read-only: Has read-only access to the environment.    read-write: Has read-write access to the environment.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.membership.create(
                ctx, environment_id=value, user_arn=value, permissions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.membership.create environment_id=value, user_arn=value, permissions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="create_environment_membership",
        op_kwargs={
            "environmentId": environment_id,
            "userArn": user_arn,
            "permissions": permissions,
        },
    )


async def delete(hub, ctx, environment_id: str, user_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an environment member from an Cloud9 development environment.

    Args:
        environment_id(str): The ID of the environment to delete the environment member from.
        user_arn(str): The Amazon Resource Name (ARN) of the environment member to delete from the environment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.membership.delete(
                ctx, environment_id=value, user_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.membership.delete environment_id=value, user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="delete_environment_membership",
        op_kwargs={"environmentId": environment_id, "userArn": user_arn},
    )


async def describe_all(
    hub,
    ctx,
    user_arn: str = None,
    environment_id: str = None,
    permissions: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about environment members for an Cloud9 development environment.

    Args:
        user_arn(str, optional): The Amazon Resource Name (ARN) of an individual environment member to get information about. If no value is specified, information about all environment members are returned. Defaults to None.
        environment_id(str, optional): The ID of the environment to get environment member information about. Defaults to None.
        permissions(List, optional): The type of environment member permissions to get information about. Available values include:    owner: Owns the environment.    read-only: Has read-only access to the environment.    read-write: Has read-write access to the environment.   If no value is specified, information about all environment members are returned. Defaults to None.
        next_token(str, optional): During a previous call, if there are more than 25 items in the list, only the first 25 items are returned, along with a unique string called a next token. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. Defaults to None.
        max_results(int, optional): The maximum number of environment members to get information about. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.membership.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.membership.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="describe_environment_memberships",
        op_kwargs={
            "userArn": user_arn,
            "environmentId": environment_id,
            "permissions": permissions,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, environment_id: str, user_arn: str, permissions: str
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the settings of an existing environment member for an Cloud9 development environment.

    Args:
        environment_id(str): The ID of the environment for the environment member whose settings you want to change.
        user_arn(str): The Amazon Resource Name (ARN) of the environment member whose settings you want to change.
        permissions(str): The replacement type of environment member permissions you want to associate with this environment member. Available values include:    read-only: Has read-only access to the environment.    read-write: Has read-write access to the environment.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.membership.update(
                ctx, environment_id=value, user_arn=value, permissions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.membership.update environment_id=value, user_arn=value, permissions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="update_environment_membership",
        op_kwargs={
            "environmentId": environment_id,
            "userArn": user_arn,
            "permissions": permissions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    instance_id: str,
    integration_type: str,
    integration_arn: str,
    source_application_url: str,
    source_application_name: str,
    source_type: str,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an AppIntegration association with an Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        integration_type(str): The type of information to be ingested.
        integration_arn(str): The Amazon Resource Name (ARN) of the integration.
        source_application_url(str): The URL for the external application.
        source_application_name(str): The name of the external application.
        source_type(str): The type of the data source.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.integration_association.create(
                ctx,
                instance_id=value,
                integration_type=value,
                integration_arn=value,
                source_application_url=value,
                source_application_name=value,
                source_type=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.integration_association.create instance_id=value, integration_type=value, integration_arn=value, source_application_url=value, source_application_name=value, source_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_integration_association",
        op_kwargs={
            "InstanceId": instance_id,
            "IntegrationType": integration_type,
            "IntegrationArn": integration_arn,
            "SourceApplicationUrl": source_application_url,
            "SourceApplicationName": source_application_name,
            "SourceType": source_type,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, instance_id: str, integration_association_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an AppIntegration association from an Amazon Connect instance. The association must not have any use cases associated with it.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        integration_association_id(str): The identifier for the AppIntegration association.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.integration_association.delete(
                ctx, instance_id=value, integration_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.integration_association.delete instance_id=value, integration_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_integration_association",
        op_kwargs={
            "InstanceId": instance_id,
            "IntegrationAssociationId": integration_association_id,
        },
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summary information about the AppIntegration associations for the specified Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.integration_association.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.integration_association.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_integration_associations",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def disable(hub, ctx, load_balancer_name: str, availability_zones: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified Availability Zones from the set of Availability Zones for the specified load balancer in EC2-Classic or a default VPC. For load balancers in a non-default VPC, use DetachLoadBalancerFromSubnets. There must be at least one Availability Zone registered with a load balancer at all times. After an Availability Zone is removed, all instances registered with the load balancer that are in the removed Availability Zone go into the OutOfService state. Then, the load balancer attempts to equally balance the traffic among its remaining Availability Zones. For more information, see Add or Remove Availability Zones in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        availability_zones(List): The Availability Zones.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.availability_zone_for_load_balancer.disable(
                ctx, load_balancer_name=value, availability_zones=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.availability_zone_for_load_balancer.disable load_balancer_name=value, availability_zones=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="disable_availability_zones_for_load_balancer",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "AvailabilityZones": availability_zones,
        },
    )


async def enable(hub, ctx, load_balancer_name: str, availability_zones: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified Availability Zones to the set of Availability Zones for the specified load balancer in EC2-Classic or a default VPC. For load balancers in a non-default VPC, use AttachLoadBalancerToSubnets. The load balancer evenly distributes requests across all its registered Availability Zones that contain instances. For more information, see Add or Remove Availability Zones in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        availability_zones(List): The Availability Zones. These must be in the same region as the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.availability_zone_for_load_balancer.enable(
                ctx, load_balancer_name=value, availability_zones=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.availability_zone_for_load_balancer.enable load_balancer_name=value, availability_zones=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="enable_availability_zones_for_load_balancer",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "AvailabilityZones": availability_zones,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, export_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing table export.

    Args:
        export_arn(str): The Amazon Resource Name (ARN) associated with the export.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.export.describe(ctx, export_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.export.describe export_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_export",
        op_kwargs={"ExportArn": export_arn},
    )


async def list_all(
    hub, ctx, table_arn: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists completed exports within the past 90 days.

    Args:
        table_arn(str, optional): The Amazon Resource Name (ARN) associated with the exported table. Defaults to None.
        max_results(int, optional): Maximum number of results to return per page. Defaults to None.
        next_token(str, optional): An optional string that, if supplied, must be copied from the output of a previous call to ListExports. When provided in this manner, the API fetches the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.export.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.export.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="list_exports",
        op_kwargs={
            "TableArn": table_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
